
#ifndef _Pix_h
#ifdef __GNUG__
#pragma once
#pragma interface
#endif
#define _Pix_h 1
typedef void* Pix;
#endif
